#############
reST Examples
#############

One-asterisk pairs make *italics*.

Is this the same as :emphasis:`the emphasis role`?


********
Chapters
********

Two-asterisk pairs make **boldface**.

Is this the same as :strong:`the strong role`?


Sections
========

Backquotes make ``code sample``.

Is this the same as :literal:`the literal role`?


Subsection
----------

There are also the :subscript:`subscript` and :superscript:`superscript`
roles. 

Subsubsection
^^^^^^^^^^^^^

And there's the elusive, enigmatic :title-reference:`title-reference
role`.


Paragraph
"""""""""

Is this paragraph below quotes special?



Lists
=====


* bullet 1
* bullet 2

#. number 1
#. number 2
#. number 3

  a. with a bullet
  b. and another
  #. and another with a # symbol

    (i) and parens numbering
    (#) another


What's your favorite color?

  This phrase makes many people laugh.  If they respond "red", tweak their
  nose and say "Aaaaaa".

Why is the package archive called cheeseshop?

  Because Guido's a Monty Python fan.


Even uncle ed knows that source code blocks are created with double colons
and indentation.::

  This text is indended in the source
  It's preformatted.

  Line 4 (or is that 3?)


----


And now for something completely different
==========================================


.. topic:: directives

  Monty Python has made me laugh many times, but I almost never laugh at
  Python.  Except for the import antigravity bit -- that was funny.

.. rubric:: This is some rubric text. I have no idea what it'll look like
            when it's formatted.

.. sidebar:: Directives
  :subtitle: directives are kinda cool

  .. attention:: Attention
  
  .. caution:: Caution
  
  .. danger:: Danger
  
  .. error:: Error
  
  .. hint:: Hint
  
  .. important:: Important
  
  .. note:: Note
  
  .. tip:: Tip
  
  .. warning:: Warning

